@@ -106,10 +106,13 @@ class TestLocalizedGeneration:
         generator = ScreenshotGenerator()
         result_paths = generator.generate_project(project_config, self.temp_dir)
 
-        # Should generate single screenshot
+        # Should generate single screenshot in device subdirectory
         assert len(result_paths) == 1
         assert result_paths[0].exists()
-        assert result_paths[0].parent == self.output_dir
+        # Path structure is now: output_dir/device/screenshot.png
+        assert result_paths[0].parent.parent == self.output_dir
+        # Verify device subdirectory was created
+        assert "iPhone_15" in result_paths[0].parent.name
 
     def test_localized_generation_creates_language_directories(self):
         """Test that localized generation creates language-specific directories."""
@@ -155,9 +158,9 @@ class TestLocalizedGeneration:
         assert ja_dir.exists()
 
         # Check screenshots exist in each language directory with device subdirectory
-        assert (en_dir / "iPhone_15_Pro_Portrait" / "welcome.png").exists()
-        assert (es_dir / "iPhone_15_Pro_Portrait" / "welcome.png").exists()
-        assert (ja_dir / "iPhone_15_Pro_Portrait" / "welcome.png").exists()
+        assert (en_dir / "iPhone_15_-_Black_-_Portrait" / "welcome.png").exists()
+        assert (es_dir / "iPhone_15_-_Black_-_Portrait" / "welcome.png").exists()
+        assert (ja_dir / "iPhone_15_-_Black_-_Portrait" / "welcome.png").exists()
 
     def test_localized_generation_multiple_screenshots(self):
         """Test localized generation with multiple screenshots."""
@@ -208,16 +211,16 @@ class TestLocalizedGeneration:
 
         # Check all combinations exist in device subdirectories
         assert (
-            self.output_dir / "en" / "iPhone_15_Pro_Portrait" / "welcome.png"
+            self.output_dir / "en" / "iPhone_15_-_Black_-_Portrait" / "welcome.png"
         ).exists()
         assert (
-            self.output_dir / "en" / "iPhone_15_Pro_Portrait" / "settings.png"
+            self.output_dir / "en" / "iPhone_15_-_Black_-_Portrait" / "settings.png"
         ).exists()
         assert (
-            self.output_dir / "es" / "iPhone_15_Pro_Portrait" / "welcome.png"
+            self.output_dir / "es" / "iPhone_15_-_Black_-_Portrait" / "welcome.png"
         ).exists()
         assert (
-            self.output_dir / "es" / "iPhone_15_Pro_Portrait" / "settings.png"
+            self.output_dir / "es" / "iPhone_15_-_Black_-_Portrait" / "settings.png"
         ).exists()
 
     def test_localized_generation_creates_xcstrings_when_missing(self):
@@ -334,7 +337,7 @@ class TestLocalizedGeneration:
         """Test localized generation with device frame."""
         project_config = ProjectConfig(
             project=ProjectInfo(name="Test Project", output_dir=str(self.output_dir)),
-            devices=["iPhone 15 Pro Portrait"],
+            devices=["iPhone 15 - Black - Portrait"],
             localization=LocalizationConfig(
                 base_language="en",
                 languages=["en", "es"],
@@ -366,10 +369,10 @@ class TestLocalizedGeneration:
 
         # Check device-specific directories are created
         assert (
-            self.output_dir / "en" / "iPhone_15_Pro_Portrait" / "welcome.png"
+            self.output_dir / "en" / "iPhone_15_-_Black_-_Portrait" / "welcome.png"
         ).exists()
         assert (
-            self.output_dir / "es" / "iPhone_15_Pro_Portrait" / "welcome.png"
+            self.output_dir / "es" / "iPhone_15_-_Black_-_Portrait" / "welcome.png"
         ).exists()
 
     def test_localized_generation_text_only_screenshots(self):
@@ -447,8 +450,8 @@ class TestLocalizedGeneration:
 
         # Screenshots should be generated with different text but same styling
         assert (
-            self.output_dir / "en" / "iPhone_15_Pro_Portrait" / "styled_text.png"
+            self.output_dir / "en" / "iPhone_15_-_Black_-_Portrait" / "styled_text.png"
         ).exists()
         assert (
-            self.output_dir / "es" / "iPhone_15_Pro_Portrait" / "styled_text.png"
+            self.output_dir / "es" / "iPhone_15_-_Black_-_Portrait" / "styled_text.png"
         ).exists()
